@@ -69,7 +69,8 @@ class BinoutData(object):
             assert (time_[0] < 0.02)
         elif self._dynasaur_definitions.get_units().second() == 1: # means s
             end_time_ = np.round(time_[-1] - time_[0], 3)
-            assert (time_[0] < 0.00001)
+            #TODO: make assert even if the condition satisfied
+            # assert (time_[0] < 0.00001)
         else:
             assert False
 
@@ -106,7 +107,9 @@ class BinoutData(object):
                     ind = np.append(ind, indices[0] + len(ids[0]) * i)
                     len_indices += len(indices[0])
 
-        for key in self.__class__.DATA_CHANNEL_TYPES:
+        available_channels = [value for value in self.__class__.DATA_CHANNEL_TYPES if value in self._binout.read(*args_)]
+
+        for key in available_channels:
             args_temp = args_ + [key]
             type_data = self._binout.read(*args_temp)
 
@@ -199,6 +202,7 @@ class BinoutData(object):
                 self._defined_types.append(json_object['array'])
                 return json_object["array"]
             else:
+                print(json_object)
                 assert False
 
     def _clean_defined_types(self):
@@ -263,41 +267,30 @@ class BinoutData(object):
         check if defined id is in binout
         :return:
         """
+        return_function = [None]
         if self._name == "secforc":
             return_function = self._check_id_in_binout("_cross_sections")
-            if not return_function[0]:
-                self._logger.emit(LOGConstants.WARNING[0], "Not valid ID: " + return_function[1] +
-                                  " . Plese check your def file!")
         elif self._name == "nodout":
             return_function = self._check_id_in_binout("_node")
-            if not return_function[0]:
-                self._logger.emit(LOGConstants.WARNING[0], "Not valid ID: " + return_function[1] +
-                                  ". Plese check your def file!")
         elif self._name == "rcforc":
             return_function = self._check_id_in_binout("_contact")
-            if not return_function[0]:
-                self._logger.emit(LOGConstants.WARNING[0], "Not valid ID: " + return_function[1] +
-                                  ". Plese check your def file!")
         elif self._name == "deforc":
             return_function = self._check_id_in_binout("_discrete")
-            if not return_function[0]:
-                self._logger.emit(LOGConstants.WARNING[0], "Not valid ID: " + return_function[1] +
-                                  ". Plese check your def file!")
         elif self._name == "elout":
             return_function = self._check_id_in_binout("_element")
-            if not return_function[0]:
-                self._logger.emit(LOGConstants.WARNING[0], "Not valid ID: " + return_function[1] +
-                                  ". Plese check your def file!")
         elif self._name == "sbtout":
             return_function = self._check_id_in_binout("_seatbelt")
-            if not return_function[0]:
-                self._logger.emit(LOGConstants.WARNING[0], "Not valid ID: " + return_function[1] +
-                                  ". Plese check your def file!")
         elif self._name == "matsum":
             return_function = self._check_id_in_binout("_energy_part")
-            if not return_function[0]:
-                self._logger.emit(LOGConstants.WARNING[0], "Not valid ID: " + return_function[1] +
-                                  ". Plese check your def file!")
+        elif self._name == "disbout":
+            return_function = self._check_id_in_binout("_disbout")
+        elif self._name == "disbout_part":
+            return_function = self._check_id_in_binout("_disbout_part")
+        elif self._name == "glstat":
+            return_function = self._check_id_in_binout("_energy_global")
+        if not return_function[0]:
+            self._logger.emit(LOGConstants.WARNING[0], "Not valid ID: " + return_function[1] +
+                              ". Plese check your def file!")
 
     def _check_id_in_binout(self, binout_name):
         '''
@@ -305,6 +298,9 @@ class BinoutData(object):
 
         :return: True or False
         '''
+        #TODO: Maybe check if the key is 0(null)
+        if binout_name == "_energy_global":
+            return True, "temp"
         ids_list = []
         dyn_def_key = getattr(self._dynasaur_definitions, binout_name)
         if len(dyn_def_key) == 0:
