@@ -1106,10 +1106,10 @@ class Nodout(BinoutData, Madymo):
 
         :return channel ids:
         '''
-        if self._code_type == CodeType.BINOUT:
-            return BinoutData.get_channels_ids_object_name(self, object_name, plugin_name)
-        else:
-            return Madymo.get_channels_ids_object_name(self, object_name, plugin_name)
+        #if self._code_type == CodeType.BINOUT:
+        return BinoutData.get_channels_ids_object_name(self, object_name, plugin_name)
+        #else:
+        #    return Madymo.get_channels_ids_object_name(self, object_name, plugin_name)
 
     def get_measurement_channel(self, id, channel_name):
         '''
@@ -1121,10 +1121,10 @@ class Nodout(BinoutData, Madymo):
         :return measurement channel:
         '''
 
-        if self._code_type == CodeType.BINOUT:
-            return BinoutData.get_measurement_channel(self, id, channel_name)
-        else:
-            return Madymo.get_measurement_channel(self, id, channel_name)
+        #if self._code_type == CodeType.BINOUT:
+        return BinoutData.get_measurement_channel(self, id, channel_name)
+        #else:
+        #    return Madymo.get_measurement_channel(self, id, channel_name)
 
     def get_time(self):
         '''
@@ -1134,10 +1134,10 @@ class Nodout(BinoutData, Madymo):
 
         :return time:
         '''
-        if self._code_type == CodeType.BINOUT:
-            return BinoutData.get_interpolated_time(self)
-        else:
-            return Madymo.get_time(self)
+        #if self._code_type == CodeType.BINOUT:
+        return BinoutData.get_interpolated_time(self)
+        #else:
+        #    return Madymo.get_time(self)
 
 
 class RCForc(BinoutData):
@@ -1215,8 +1215,9 @@ class SBTout(BinoutData):
 class Secforc(BinoutData):
     '''
     '''
-    DATA_CHANNEL_TYPES = ['x_force', 'y_force', 'z_force', 'total_force', 'x_moment', 'y_moment', 'z_moment',
-                          'total_moment', 'x_centroid', 'y_centroid', 'z_centroid', 'area']
+    DATA_CHANNEL_TYPES = ['x_force', 'y_force', 'z_force',  'x_moment', 'y_moment', 'z_moment',
+                          'x_centroid', 'y_centroid', 'z_centroid', 'total_force', 'total_moment',  'area']
+                            #'total_force', 'total_moment',  'area'
     ids_name = "ids"
 
     def __init__(self, binout, logger, dynasaur_definitions):
