@@ -229,6 +229,7 @@ class StandardFunctionsDefinition:
     MULT = "mult"
     SUB = "sub"
     ADD = "add"
+    DIVIDE = "divide"
     ABS_SUB = "abs_sub"
     ABS_ADD = "abs_add"
     DOUBLE_ABS_SUB_RES = "double_abs_sub_res"
@@ -333,3 +334,67 @@ class LoggerSCRIPT:
 class LoggerReadDynasaurDefinitionFile:
     READ = "read %s"
     DONE = "done"
+
+
+class VPSDataConstant:
+    NODOUT = "nodout"
+    NODE = "NODE"
+    SECFORC = "secforc"
+    SECTION = "SECTION"
+
+    #nodout
+    COORDINATE = "COORDINATE"
+    TRANSLATION_DISPLACEMENT = "Translational_Displacement"
+    VELOCITY = "Velocity"
+    ACCELERATION = "Acceleration"
+    ROTATION_ANGLE = "Rotational_Angle"
+    ROTATION_VELOCITY = "Rotational_Velocity"
+    ROTATION_ACCELERATION = "Rotational_Acceleration"
+
+    #secforc
+    SECTION_CENTRE_POSITION = "Section_Centre_Position"
+    SECTION_FORCE = "Section_Force"
+    SECTION_MOMENT = "Section_Moment"
+
+class DataChannelTypesNodout:
+    X_COORDINATE = "x_coordinate"
+    Y_COORDINATE = "y_coordinate"
+    Z_COORDINATE = "Z_coordinate"
+
+    X_DISPLACEMENT = "x_displacement"
+    Y_DISPLACEMENT = "y_displacement"
+    Z_DISPLACEMENT = "z_displacement"
+
+    X_VELOCITY = "x_velocity"
+    Y_VELOCITY = "y_velocity"
+    Z_VELOCITY = "z_velocity"
+
+    X_ACCELERATION = "x_acceleration"
+    Y_ACCELERATION = "y_acceleration"
+    Z_ACCELERATION = "z_acceleration"
+
+    RX_DISPLACEMENT = "rx_displacement"
+    RY_DISPLACEMENT = "ry_displacement"
+    RZ_DISPLACEMENT = "rz_displacement"
+
+    RX_VELOCITY = "rx_velocity"
+    RY_VELOCITY = "ry_velocity"
+    RZ_VELOCITY = "rz_velocity"
+
+    RX_ACCELERATION = "rx_acceleration"
+    RY_ACCELERATION = "ry_acceleration"
+    RZ_ACCELERATION = "rz_acceleration"
+
+
+class DataChannelTypesSecforc:
+    X_CENTROID = "x_centroid"
+    Y_CENTROID = "y_centroid"
+    Z_CENTROID = "z_centroid"
+
+    X_FORCE = "x_force"
+    Y_FORCE = "y_force"
+    Z_FORCE = "z_force"
+
+    X_MOMENT = "x_moment"
+    Y_MOMENT = "y_moment"
+    Z_MOMENT = "z_moment"
